@@ -4,7 +4,7 @@ import pkgutil
 
 
 def test_validate(instance):
-    resources = pkgutil.get_data('hero', 'test_schema.json')
+    resources = pkgutil.get_data('inner', 'test_schema.json')
     schema = json.loads(resources)
     validate(instance, schema)
 
